summaryrefslogtreecommitdiff
path: root/include/llvm/CodeGen
diff options
context:
space:
mode:
authorBill Wendling <isanbard@gmail.com>2010-06-29 22:34:52 +0000
committerBill Wendling <isanbard@gmail.com>2010-06-29 22:34:52 +0000
commit07d317711781d8c9268f7d6afcf1ba7eadf1d127 (patch)
tree2e2826cb827a826cfdcd2e475e9b69dfd0b1009f /include/llvm/CodeGen
parente025e966a863229feb7ad188f520ce213bb30a34 (diff)
downloadllvm-07d317711781d8c9268f7d6afcf1ba7eadf1d127.tar.gz
llvm-07d317711781d8c9268f7d6afcf1ba7eadf1d127.tar.bz2
llvm-07d317711781d8c9268f7d6afcf1ba7eadf1d127.tar.xz
Revert r107205 and r107207.
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@107215 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/llvm/CodeGen')
-rw-r--r--include/llvm/CodeGen/AsmPrinter.h2
-rw-r--r--include/llvm/CodeGen/MachineFunction.h8
2 files changed, 5 insertions, 5 deletions
diff --git a/include/llvm/CodeGen/AsmPrinter.h b/include/llvm/CodeGen/AsmPrinter.h
index 32679b5374..243ddbb5da 100644
--- a/include/llvm/CodeGen/AsmPrinter.h
+++ b/include/llvm/CodeGen/AsmPrinter.h
@@ -285,7 +285,7 @@ namespace llvm {
MCSymbol *GetCPISymbol(unsigned CPID) const;
/// GetJTISymbol - Return the symbol for the specified jump table entry.
- MCSymbol *GetJTISymbol(unsigned JTID, bool PassToLinker = false) const;
+ MCSymbol *GetJTISymbol(unsigned JTID, bool isLinkerPrivate = false) const;
/// GetJTSetSymbol - Return the symbol for the specified jump table .set
/// FIXME: privatize to AsmPrinter.
diff --git a/include/llvm/CodeGen/MachineFunction.h b/include/llvm/CodeGen/MachineFunction.h
index ce8785857e..409d13ee3f 100644
--- a/include/llvm/CodeGen/MachineFunction.h
+++ b/include/llvm/CodeGen/MachineFunction.h
@@ -402,10 +402,10 @@ public:
//
/// getJTISymbol - Return the MCSymbol for the specified non-empty jump table.
- /// If PassToLinker is specified, an 'l' label is returned, otherwise a normal
- /// 'L' label is returned.
- MCSymbol *getJTISymbol(unsigned JTI, MCContext &Ctx,
- bool PassToLinker = false) const;
+ /// If isLinkerPrivate is specified, an 'l' label is returned, otherwise a
+ /// normal 'L' label is returned.
+ MCSymbol *getJTISymbol(unsigned JTI, MCContext &Ctx,
+ bool isLinkerPrivate = false) const;
};
//===--------------------------------------------------------------------===//